# Arthur Common

Arthur Common is a library that contains common operations between Arthur platform services.

## Installation

To install the package, use [Poetry](https://python-poetry.org/):

```bash
poetry add arthur-common
```

or pip

```bash
pip install arthur-common
```

## Requirements

- Python 3.12

## Development

To set up the development environment, ensure you have [Poetry](https://python-poetry.org/) installed, then run:

```bash
poetry env use 3.12
poetry install
```

### Running Tests

This project uses [pytest](https://pytest.org/) for testing. To run the tests, execute:

```bash
poetry run pytest
```

## License

This project is licensed under the MIT License.

## Authors

- Arthur <engineering@arthur.ai>
